@@ -4,17 +4,22 @@ require "influxdb/logging"
 require "influxdb/max_queue"
 require "influxdb/point_value"
 require "influxdb/config"
+require "influxdb/timestamp_conversion"
 
 require "influxdb/writer/async"
 require "influxdb/writer/udp"
 
-require "influxdb/query/core"
+require "influxdb/query/batch"
+require "influxdb/query/builder"
 require "influxdb/query/cluster"
-require "influxdb/query/database"
-require "influxdb/query/user"
 require "influxdb/query/continuous_query"
+require "influxdb/query/core"
+require "influxdb/query/core"
+require "influxdb/query/database"
+require "influxdb/query/measurement"
 require "influxdb/query/retention_policy"
 require "influxdb/query/series"
+require "influxdb/query/user"
 
 require "influxdb/client/http"
 require "influxdb/client"
