@@ -45,13 +45,12 @@ module InfluxDB
       retry_count = 0
 
       begin
-        http = Net::HTTP.new(host, config.port)
+        http = build_http(host, config.port)
         http.open_timeout = config.open_timeout
         http.read_timeout = config.read_timeout
 
         http = setup_ssl(http)
         yield http
-
       rescue *InfluxDB::NON_RECOVERABLE_EXCEPTIONS => e
         raise InfluxDB::ConnectionError, InfluxDB::NON_RECOVERABLE_MESSAGE
       rescue Timeout::Error, *InfluxDB::RECOVERABLE_EXCEPTIONS => e
@@ -59,7 +58,8 @@ module InfluxDB
         unless (config.retry == -1 || retry_count <= config.retry) && !stopped?
           raise InfluxDB::ConnectionError, "Tried #{retry_count - 1} times to reconnect but failed."
         end
-        log :error, "Failed to contact host #{host}: #{e.inspect} - retrying in #{delay}s."
+
+        log(:warn) { "Failed to contact host #{host}: #{e.inspect} - retrying in #{delay}s." }
         sleep delay
         delay = [config.max_delay, delay * 2].min
         retry
@@ -79,10 +79,12 @@ module InfluxDB
     end
 
     def resolve_error(response)
-      if response =~ /Couldn\'t find series/
+      case response
+      when /Couldn\'t find series/
         raise InfluxDB::SeriesNotFound, response
+      else
+        raise InfluxDB::Error, response
       end
-      raise InfluxDB::Error, response
     end
 
     def handle_successful_response(response, options)
@@ -90,18 +92,19 @@ module InfluxDB
         parsed_response = response.body.each_line.with_object({}) do |line, parsed|
           parsed.merge!(JSON.parse(line)) { |_key, oldval, newval| oldval + newval }
         end
-      elsif response.body
+      elsif (body = response.body) && (body != "")
         parsed_response = JSON.parse(response.body)
       end
 
       errors = errors_from_response(parsed_response)
-
       raise InfluxDB::QueryError, errors if errors
+
       options.fetch(:parse, false) ? parsed_response : response
     end
 
     def errors_from_response(parsed_resp)
       return unless parsed_resp.is_a?(Hash)
+
       parsed_resp
         .fetch('results', [])
         .fetch(0, {})
@@ -130,5 +133,17 @@ module InfluxDB
       end
       store
     end
+
+    # Builds an http instance, taking into account any configured
+    # proxy configuration
+    def build_http(host, port)
+      if config.proxy_addr
+        Net::HTTP.new(host, port, config.proxy_addr, config.proxy_port)
+      else
+        Net::HTTP.new(host, port)
+      end
+    end
   end
+  # rubocop:enable Metrics/MethodLength
+  # rubocop:enable Metrics/AbcSize
 end
