@@ -10,7 +10,6 @@ module InfluxDB
         end
 
         query % params
-
       rescue KeyError => e
         raise ArgumentError, e.message
       end
@@ -18,7 +17,7 @@ module InfluxDB
       def quote(param)
         case param
         when String, Symbol
-          "'" + param.to_s.gsub(/['"\\\x0]/, '\\\\\0') + "'"
+          "'".freeze + param.to_s.gsub(/['"\\\x0]/, '\\\\\0') + "'".freeze
         when Integer, Float, TrueClass, FalseClass
           param.to_s
         else
