@@ -1,8 +1,8 @@
+require_relative 'batch'
 require_relative 'builder'
 
 module InfluxDB
   module Query # :nodoc: all
-    # rubocop:disable Metrics/AbcSize
     module Core
       def builder
         @builder ||= Builder.new
@@ -17,15 +17,17 @@ module InfluxDB
         ping.header['x-influxdb-version']
       end
 
-      # rubocop:disable Metrics/MethodLength
-      def query(query, opts = {})
-        query = builder.build(query, opts[:params])
-        denormalize = opts.fetch(:denormalize, config.denormalize)
-        json_streaming = !opts.fetch(:chunk_size, config.chunk_size).nil?
+      def query( # rubocop:disable Metrics/MethodLength
+        query,
+        params:       nil,
+        denormalize:  config.denormalize,
+        chunk_size:   config.chunk_size,
+        **opts
+      )
+        query = builder.build(query, params)
 
-        params = query_params(query, opts)
-        url = full_url("/query".freeze, params)
-        series = fetch_series(get(url, parse: true, json_streaming: json_streaming))
+        url = full_url("/query".freeze, **query_params(query, **opts))
+        series = fetch_series(get(url, parse: true, json_streaming: !chunk_size.nil?))
 
         if block_given?
           series.each do |s|
@@ -36,7 +38,10 @@ module InfluxDB
           denormalize ? denormalized_series_list(series) : series
         end
       end
-      # rubocop:enable Metrics/MethodLength
+
+      def batch(&block)
+        Batch.new self, &block
+      end
 
       # Example:
       # write_points([
@@ -55,7 +60,7 @@ module InfluxDB
         data = data.is_a?(Array) ? data : [data]
         payload = generate_payload(data)
         writer.write(payload, precision, retention_policy, database)
-      rescue => e
+      rescue StandardError => e
         raise e unless config.discard_write_errors
 
         log :error, "Cannot write data: #{e.inspect}"
@@ -69,24 +74,24 @@ module InfluxDB
 
       def write(data, precision, retention_policy = nil, database = nil)
         params = {
-          db:         database || config.database,
-          precision:  precision || config.time_precision,
+          db:        database || config.database,
+          precision: precision || config.time_precision,
         }
 
         params[:rp] = retention_policy if retention_policy
-        url = full_url("/write", params)
+        url = full_url("/write", **params)
         post(url, data)
       end
 
       private
 
-      # rubocop:disable Metrics/MethodLength
-      def query_params(query, opts)
-        precision   = opts.fetch(:precision, config.time_precision)
-        epoch       = opts.fetch(:epoch, config.epoch)
-        chunk_size  = opts.fetch(:chunk_size, config.chunk_size)
-        database    = opts.fetch(:database, config.database)
-
+      def query_params(
+        query,
+        precision:  config.time_precision,
+        epoch:      config.epoch,
+        chunk_size: config.chunk_size,
+        database:   config.database
+      )
         params = { q: query, db: database }
         params[:precision] = precision if precision
         params[:epoch]     = epoch     if epoch
@@ -98,7 +103,6 @@ module InfluxDB
 
         params
       end
-      # rubocop:enable Metrics/MethodLength
 
       def denormalized_series_list(series)
         series.map do |s|
@@ -117,15 +121,19 @@ module InfluxDB
       end
 
       def generate_payload(data)
-        data.map do |point|
-          InfluxDB::PointValue.new(point).dump
-        end.join("\n".freeze)
+        data.map { |point| generate_point(point) }.join("\n".freeze)
       end
 
-      def execute(query, options = {})
+      def generate_point(point)
+        InfluxDB::PointValue.new(point).dump
+      rescue InfluxDB::LineProtocolError => e
+        (log :error, "Cannot write data: #{e.inspect}") && nil
+      end
+
+      def execute(query, db: nil, **options)
         params = { q: query }
-        params[:db] = options.delete(:db) if options.key?(:db)
-        url = full_url("/query".freeze, params)
+        params[:db] = db if db
+        url = full_url("/query".freeze, **params)
         get(url, options)
       end
 
@@ -136,20 +144,25 @@ module InfluxDB
       end
 
       def raw_values(series)
-        series.select { |k, _| %w(columns values).include?(k) }
+        series.select { |k, _| %w[columns values].include?(k) }
       end
 
-      def full_url(path, params = {})
+      def full_url(path, **params)
         if config.auth_method == "params".freeze
           params[:u] = config.username
           params[:p] = config.password
         end
 
-        query = params.map do |k, v|
+        URI::Generic.build(
+          path:  File.join(config.prefix, path),
+          query: cgi_escape_params(params)
+        ).to_s
+      end
+
+      def cgi_escape_params(params)
+        params.map do |k, v|
           [CGI.escape(k.to_s), "=".freeze, CGI.escape(v.to_s)].join
         end.join("&".freeze)
-
-        URI::Generic.build(path: File.join(config.prefix, path), query: query).to_s
       end
     end
   end
