@@ -2,11 +2,11 @@ module InfluxDB
   module Query
     module Database # :nodoc:
       def create_database(name = nil)
-        execute("CREATE DATABASE #{name || config.database}")
+        execute("CREATE DATABASE \"#{name || config.database}\"")
       end
 
       def delete_database(name = nil)
-        execute("DROP DATABASE #{name || config.database}")
+        execute("DROP DATABASE \"#{name || config.database}\"")
       end
 
       def list_databases
