@@ -3,29 +3,26 @@ require "json"
 
 describe InfluxDB::Client do
   let(:subject) do
-    described_class.new(
-      "database",
-      {
-        host: "influxdb.test",
-        port: 9999,
-        username: "username",
-        password: "password",
-        time_precision: "s"
-      }.merge(args)
-    )
+    described_class.new \
+      database:       "database",
+      host:           "influxdb.test",
+      port:           9999,
+      username:       "username",
+      password:       "password",
+      time_precision: "s"
   end
 
-  let(:args) { {} }
-
   describe "#list_continuous_queries" do
     let(:query) { "SHOW CONTINUOUS QUERIES" }
     let(:database) { "testdb" }
     let(:response) do
       { "results" => [{ "statement_id" => 0,
-                        "series" => [{ "name" => "otherdb", "columns" => %w(name query),
-                                       "values" => [["clicks_per_hour", "CREATE CONTINUOUS QUERY clicks_per_hour ON otherdb BEGIN SELECT count(name) INTO \"otherdb\".\"default\".clicksCount_1h FROM \"otherdb\".\"default\".clicks GROUP BY time(1h) END"]] },
-                                     { "name" => "testdb", "columns" => %w(name query),
-                                       "values" => [["event_counts", "CREATE CONTINUOUS QUERY event_counts ON testdb BEGIN SELECT count(type) INTO \"testdb\".\"default\".typeCount_10m_byType FROM \"testdb\".\"default\".events GROUP BY time(10m), type END"]] }] }] }
+                        "series"       => [{ "name"    => "otherdb",
+                                             "columns" => %w[name query],
+                                             "values"  => [["clicks_per_hour", "CREATE CONTINUOUS QUERY clicks_per_hour ON otherdb BEGIN SELECT count(name) INTO \"otherdb\".\"default\".clicksCount_1h FROM \"otherdb\".\"default\".clicks GROUP BY time(1h) END"]] },
+                                           { "name"    => "testdb",
+                                             "columns" => %w[name query],
+                                             "values"  => [["event_counts", "CREATE CONTINUOUS QUERY event_counts ON testdb BEGIN SELECT count(type) INTO \"testdb\".\"default\".typeCount_10m_byType FROM \"testdb\".\"default\".events GROUP BY time(10m), type END"]] }] }] }
     end
 
     let(:expected_result) do
@@ -107,11 +104,11 @@ describe InfluxDB::Client do
   describe "#delete_continuous_query" do
     let(:name) { "event_counts_per_10m_by_type" }
     let(:database) { "testdb" }
-    let(:query) { "DROP CONTINUOUS QUERY #{name} ON #{database}" }
+    let(:query) { "DROP CONTINUOUS QUERY \"#{name}\" ON \"#{database}\"" }
+
     before do
-      stub_request(:get, "http://influxdb.test:9999/query").with(
-        query: { u: "username", p: "password", q: query }
-      )
+      stub_request(:get, "http://influxdb.test:9999/query")
+        .with(query: { u: "username", p: "password", q: query })
     end
 
     it "should GET to remove continuous query" do
