@@ -2,23 +2,22 @@ require "spec_helper"
 
 describe InfluxDB::Client do
   let(:subject) do
-    described_class.new "database", {
-      host: "influxdb.test",
-      port: 9999,
-      username: "username",
-      password: "password",
+    described_class.new \
+      database:       "database",
+      host:           "influxdb.test",
+      port:           9999,
+      username:       "username",
+      password:       "password",
       time_precision: "s"
-    }.merge(args)
   end
 
-  let(:args) { {} }
-
   describe "#query" do
     let(:query) { "SELECT value FROM requests_per_minute WHERE time > 1437019900" }
-    let(:response) do
+
+    let :response do
       { "results" => [{ "statement_id" => 0,
-                        "series" => [{ "name" => "requests_per_minute",
-                                       "columns" => %w(time value) }] }] }
+                        "series"       => [{ "name"    => "requests_per_minute",
+                                             "columns" => %w[time value] }] }] }
     end
 
     before do
