@@ -3,31 +3,27 @@ require "json"
 
 describe InfluxDB::Client do
   let(:subject) do
-    described_class.new(
-      "database",
-      {
-        host: "influxdb.test",
-        port: 9999,
-        username: "username",
-        password: "password",
-        time_precision: "s"
-      }.merge(args)
-    )
+    described_class.new \
+      database:       "database",
+      host:           "influxdb.test",
+      port:           9999,
+      username:       "username",
+      password:       "password",
+      time_precision: "s"
   end
 
-  let(:args) { {} }
   let(:query) { nil }
   let(:response) { { "results" => [{ "statement_id" => 0 }] } }
 
   before do
-    stub_request(:get, "http://influxdb.test:9999/query").with(
-      query: { u: "username", p: "password", q: query }
-    ).to_return(body: JSON.generate(response))
+    stub_request(:get, "http://influxdb.test:9999/query")
+      .with(query: { u: "username", p: "password", q: query })
+      .to_return(body: JSON.generate(response))
   end
 
   describe "#create_database" do
     describe "from param" do
-      let(:query) { "CREATE DATABASE foo" }
+      let(:query) { "CREATE DATABASE \"foo\"" }
 
       it "should GET to create a new database" do
         expect(subject.create_database("foo")).to be_a(Net::HTTPOK)
@@ -35,7 +31,7 @@ describe InfluxDB::Client do
     end
 
     describe "from config" do
-      let(:query) { "CREATE DATABASE database" }
+      let(:query) { "CREATE DATABASE \"database\"" }
 
       it "should GET to create a new database using database name from config" do
         expect(subject.create_database).to be_a(Net::HTTPOK)
@@ -45,7 +41,7 @@ describe InfluxDB::Client do
 
   describe "#delete_database" do
     describe "from param" do
-      let(:query) { "DROP DATABASE foo" }
+      let(:query) { "DROP DATABASE \"foo\"" }
 
       it "should GET to remove a database" do
         expect(subject.delete_database("foo")).to be_a(Net::HTTPOK)
@@ -53,7 +49,7 @@ describe InfluxDB::Client do
     end
 
     describe "from config" do
-      let(:query) { "DROP DATABASE database" }
+      let(:query) { "DROP DATABASE \"database\"" }
 
       it "should GET to remove a database using database name from config" do
         expect(subject.delete_database).to be_a(Net::HTTPOK)
