@@ -1,7 +1,10 @@
 require "spec_helper"
 
 describe InfluxDB::Client do
-  let(:client) { described_class.new(udp: { host: "localhost", port: 44_444 }) }
+  let(:socket) { UDPSocket.new.tap { |s| s.bind "localhost", 0 } }
+  after        { socket.close rescue nil }
+
+  let(:client) { described_class.new(udp: { host: "localhost", port: socket.addr[1] }) }
 
   specify { expect(client.writer).to be_a(InfluxDB::Writer::UDP) }
 
@@ -9,32 +12,23 @@ describe InfluxDB::Client do
     let(:message) { 'responses,region=eu value=5i' }
 
     it "sends a UDP packet" do
-      s = UDPSocket.new
-      s.bind("localhost", 44_444)
-
       client.write_point("responses", values: { value: 5 }, tags: { region: 'eu' })
 
-      rec_message = s.recvfrom(30).first
+      rec_message = socket.recvfrom(30).first
       expect(rec_message).to eq message
-
-      s.close
     end
   end
 
   describe "#write with discard_write_errors" do
     let(:client) do
-      described_class.new(
-        udp: { host: "localhost", port: 44_444 },
+      described_class.new \
+        udp:                  { host: "localhost", port: socket.addr[1] },
         discard_write_errors: true
-      )
     end
 
     it "doesn't raise" do
-      s = UDPSocket.new
-      s.bind("localhost", 44_444)
-
       client.write_point("responses", values: { value: 5 }, tags: { region: 'eu' })
-      s.close
+      socket.close
 
       client.write_point("responses", values: { value: 7 }, tags: { region: 'eu' })
 
