@@ -5,11 +5,11 @@ describe InfluxDB::Client do
   let(:subject) do
     described_class.new(
       "database",
-      {
-        host: "influxdb.test",
-        port: 9999,
-        username: "username",
-        password: "password",
+      **{
+        host:           "influxdb.test",
+        port:           9999,
+        username:       "username",
+        password:       "password",
         time_precision: "s"
       }.merge(args)
     )
@@ -46,7 +46,9 @@ describe InfluxDB::Client do
 
     it "escapes params" do
       url = subject.send(:full_url, "/unknown", value: ' !@#$%^&*()/\\_+-=?|`~')
-      expect(url).to include("value=+%21%40%23%24%25%5E%26%2A%28%29%2F%5C_%2B-%3D%3F%7C%60%7E")
+      encoded_fragment = "value=+%21%40%23%24%25%5E%26%2A%28%29%2F%5C_%2B-%3D%3F%7C%60"
+      encoded_fragment << (RUBY_VERSION >= "2.5.0" ? "~" : "%7E")
+      expect(url).to include(encoded_fragment)
     end
 
     context "with prefix" do
