@@ -8,6 +8,10 @@ describe InfluxDB::Logging do
     def write_to_log(level, message)
       log(level, message)
     end
+
+    def block_log(level, &block)
+      log(level, &block)
+    end
   end
 
   around do |example|
@@ -34,6 +38,9 @@ describe InfluxDB::Logging do
   context "when logging is disabled" do
     subject { LoggerTest.new }
     it "does not log" do
+      pending "The test doesn't work since bugfix in rspec-mocks 3.10.1 " \
+              "(https://github.com/rspec/rspec-mocks/pull/1357)"
+
       InfluxDB::Logging.logger = false
       expect(InfluxDB::Logging.logger).not_to receive(:debug)
       subject.write_to_log(:debug, 'test')
@@ -43,9 +50,16 @@ describe InfluxDB::Logging do
   context "when included in classes" do
     subject { LoggerTest.new }
 
-    it "logs" do
-      expect(InfluxDB::Logging.logger).to receive(:debug).with(an_instance_of(String)).once
-      subject.write_to_log(:debug, 'test')
+    it "logs with string message" do
+      expect(InfluxDB::Logging.logger).to receive(:info).with(an_instance_of(String)).once
+      subject.write_to_log(:info, 'test')
+    end
+
+    it "logs with block message" do
+      msg = double("message")
+      expect(msg).to receive(:expensive_message).and_return("42")
+      expect(InfluxDB::Logging.logger).to receive(:info).and_yield.once
+      subject.block_log(:info) { msg.expensive_message }
     end
   end
 end
